@@ -5,6 +5,7 @@
 */
 
 #include "configurepluginslistwidget.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLineEditEventHandler>
 #include <KLocalizedString>
@@ -25,13 +26,13 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     , mListWidget(new QTreeWidget(this))
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QLatin1StringView("mainlayout"));
+    mainLayout->setObjectName("mainlayout"_L1);
     mainLayout->setContentsMargins({});
     mainLayout->setSpacing(0);
 
     mListWidget->setSortingEnabled(true);
     mListWidget->sortItems(0, Qt::AscendingOrder);
-    mListWidget->setObjectName(QLatin1StringView("listwidget"));
+    mListWidget->setObjectName("listwidget"_L1);
     mListWidget->setHeaderHidden(true);
     mListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
     mListWidget->setColumnCount(2);
@@ -40,7 +41,7 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
     mListWidget->header()->setStretchLastSection(false);
 
     mTreeWidgetSearchLineEdit = new KTreeWidgetSearchLineWidget(this, mListWidget);
-    mTreeWidgetSearchLineEdit->setObjectName(QLatin1StringView("mTreeWidgetSearchLineEdit"));
+    mTreeWidgetSearchLineEdit->setObjectName("mTreeWidgetSearchLineEdit"_L1);
     mTreeWidgetSearchLineEdit->searchLine()->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::BottomEdge}));
     KLineEditEventHandler::catchReturnKey(mTreeWidgetSearchLineEdit->searchLine());
 
