@@ -13,6 +13,8 @@
 */
 
 #include "addresseelineedit.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "addresseelineedit_p.h"
 #include "addresseelineeditmanager.h"
 #include "addresseelineeditutil.h"
@@ -39,6 +41,7 @@
 #include <KLocalizedString>
 #include <KStandardShortcut>
 
+#include "addressline/completionconfiguredialog/completionconfiguredialog.h"
 #include <Akonadi/ContactGroupExpandJob>
 #include <KContacts/VCardDrag>
 #include <KMessageBox>
@@ -53,13 +56,12 @@
 #include <QMimeData>
 #include <QMouseEvent>
 #include <QObject>
-#include <addressline/completionconfiguredialog/completionconfiguredialog.h>
 
 using namespace PimCommon;
 
 inline bool itemIsHeader(const QListWidgetItem *item)
 {
-    return item && !item->text().startsWith(QLatin1String("     "));
+    return item && !item->text().startsWith("     "_L1);
 }
 
 // needs to be unique, but the actual name doesn't matter much
@@ -260,17 +262,14 @@ void AddresseeLineEdit::paste()
 void AddresseeLineEdit::mouseReleaseEvent(QMouseEvent *event)
 {
     // reimplemented from QLineEdit::mouseReleaseEvent()
-#ifndef QT_NO_CLIPBOARD
     if (d->useCompletion() && QApplication::clipboard()->supportsSelection() && !isReadOnly() && event->button() == Qt::MiddleButton) {
         d->setSmartPaste(true);
     }
-#endif
 
     KLineEdit::mouseReleaseEvent(event);
     d->setSmartPaste(false);
 }
 
-#ifndef QT_NO_DRAGANDDROP
 void AddresseeLineEdit::dropEvent(QDropEvent *event)
 {
     const QMimeData *md = event->mimeData();
@@ -294,7 +293,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
         for (const QUrl &url : urls) {
             // First, let's deal with mailto Urls. The path() part contains the
             // email-address.
-            if (url.scheme() == QLatin1String("mailto")) {
+            if (url.scheme() == "mailto"_L1) {
                 KContacts::Addressee addressee;
                 KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
                 email.setPreferred(true);
@@ -354,13 +353,13 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                 bool mailtoURL = false;
                 // append the mailto URLs
                 for (const QUrl &url : uriList) {
-                    if (url.scheme() == QLatin1String("mailto")) {
+                    if (url.scheme() == "mailto"_L1) {
                         mailtoURL = true;
                         QString address;
                         address = QUrl::fromPercentEncoding(url.path().toLatin1());
                         address = KCodecs::decodeRFC2047String(address);
                         if (!contents.isEmpty()) {
-                            contents.append(QLatin1String(", "));
+                            contents.append(", "_L1);
                         }
                         contents.append(address);
                     }
@@ -378,7 +377,7 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
                     if (!addrs.isEmpty()) {
                         if (addrs.count() == 1) {
                             QUrl url(dropData);
-                            if (url.scheme() == QLatin1String("mailto")) {
+                            if (url.scheme() == "mailto"_L1) {
                                 KContacts::Addressee addressee;
                                 KContacts::Email email(KEmailAddress::decodeMailtoUrl(url));
                                 email.setPreferred(true);
@@ -406,8 +405,6 @@ void AddresseeLineEdit::dropEvent(QDropEvent *event)
     }
 }
 
-#endif // QT_NO_DRAGANDDROP
-
 void AddresseeLineEdit::groupExpandResult(KJob *job)
 {
     auto expandJob = qobject_cast<Akonadi::ContactGroupExpandJob *>(job);
@@ -446,7 +443,7 @@ void AddresseeLineEdit::insertEmails(const QStringList &emails)
     // multiple emails, let the user choose one
     QMenu menu(this);
     menu.setTitle(i18n("Select email from contact"));
-    menu.setObjectName(QLatin1StringView("Addresschooser"));
+    menu.setObjectName("Addresschooser"_L1);
     for (const QString &email : emails) {
         menu.addAction(email);
     }
@@ -545,7 +542,6 @@ void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight,
     addContact(emails, addr, weight, source, append);
 }
 
-#ifndef QT_NO_CONTEXTMENU
 void AddresseeLineEdit::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu *menu = createStandardContextMenu();
@@ -590,8 +586,6 @@ QMenu *AddresseeLineEdit::createStandardContextMenu()
     return menu;
 }
 
-#endif
-
 bool AddresseeLineEdit::canDeleteLineEdit() const
 {
     return d->canDeleteLineEdit();
@@ -923,7 +917,7 @@ void AddresseeLineEdit::expandGroups()
         addresses.removeAll(group.name());
         expandJob->start();
     }
-    setText(addresses.join(QLatin1String(", ")));
+    setText(addresses.join(", "_L1));
     d->groupsClear();
 }
 
