@@ -34,7 +34,7 @@ public:
     void init();
     void setCompletedItems(const QStringList &items, bool autoSuggest);
     void addCompletionItem(const QString &string, int weight, int source, const QStringList *keyWords = nullptr);
-    const QStringList adjustedCompletionItems(bool fullSearch);
+    [[nodiscard]] const QStringList adjustedCompletionItems(bool fullSearch);
     void updateSearchString();
     void startSearches();
     void akonadiPerformSearch();
@@ -107,7 +107,7 @@ public Q_SLOTS:
     void slotToggleExpandGroups(bool);
     void slotShowOUChanged(bool);
 
-private Q_SLOTS:
+private:
     void slotCompletion();
     void slotPopupCompletion(const QString &);
     void slotReturnPressed(const QString &);
@@ -121,7 +121,6 @@ private Q_SLOTS:
     void searchInBaloo();
     void slotTriggerDelayedQueries();
 
-private:
     AddresseeLineEdit *const q;
     QToolButton *mToolButton = nullptr;
     QTimer *const mDelayedQueryTimer;
